@@ -9,6 +9,14 @@ import (
 	"strings"
 )
 
+func HasProjectID() bool {
+	return hasEnvVar(HCPProjectID)
+}
+
+func HasOrganizationID() bool {
+	return hasEnvVar(HCPOrganizationID)
+}
+
 func HasClientID() bool {
 	return hasEnvVar(HCPClientID)
 }
