@@ -20,6 +20,11 @@ import (
 	plugingetter "github.com/hashicorp/packer/packer/plugin-getter"
 )
 
+var defaultChecksummer = plugingetter.Checksummer{
+	Type: "sha256",
+	Hash: sha256.New(),
+}
+
 // PluginConfig helps load and use packer plugins
 type PluginConfig struct {
 	KnownPluginFolders []string
@@ -80,7 +85,8 @@ func (c *PluginConfig) Discover() error {
 	}
 
 	if len(c.KnownPluginFolders) == 0 {
-		c.KnownPluginFolders = PluginFolders()
+		//PluginFolders should match the call in github.com/hahicorp/packer/main.go#loadConfig
+		c.KnownPluginFolders = PluginFolders(".")
 	}
 
 	// TODO after JSON is deprecated remove support for legacy component plugins.
@@ -227,6 +233,14 @@ func (c *PluginConfig) discoverSingle(glob string) (map[string]string, error) {
 			continue
 		}
 
+		if strings.Contains(strings.ToUpper(file), defaultChecksummer.FileExt()) {
+			log.Printf(
+				"[TRACE] Ignoring plugin match %s, which looks to be a checksum file",
+				match)
+			continue
+
+		}
+
 		// If the filename has a ".", trim up to there
 		if idx := strings.Index(file, ".exe"); idx >= 0 {
 			file = file[:idx]
@@ -239,7 +253,11 @@ func (c *PluginConfig) discoverSingle(glob string) (map[string]string, error) {
 		pluginName = strings.SplitN(pluginName, "_", 2)[0]
 
 		log.Printf("[INFO] Discovered potential plugin: %s = %s", pluginName, match)
-		res[pluginName] = match
+		pluginPath, err := filepath.Abs(match)
+		if err != nil {
+			pluginPath = match
+		}
+		res[pluginName] = pluginPath
 	}
 
 	return res, nil
@@ -379,7 +397,7 @@ func (c *PluginConfig) discoverInstalledComponents(path string) error {
 		APIVersionMajor: pluginsdk.APIVersionMajor,
 		APIVersionMinor: pluginsdk.APIVersionMinor,
 		Checksummers: []plugingetter.Checksummer{
-			{Type: "sha256", Hash: sha256.New()},
+			defaultChecksummer,
 		},
 	}
 
